@@ -6,8 +6,8 @@ These exceptions are tied to how **web-poet** operates.
 """
 
 
-class RequestBackendError(Exception):
-    """The ``web_poet.request_backend_var`` had its contents accessed but there
+class RequestDownloaderVarError(Exception):
+    """The ``web_poet.request_downloader_var`` had its contents accessed but there
     wasn't any value set during the time requests are executed.
 
     See the documentation section about :ref:`setting up the contextvars <setup-contextvars>`
@@ -15,3 +15,13 @@ class RequestBackendError(Exception):
     """
 
     pass
+
+
+class Retry(ValueError):
+    """The page object found that the input data is partial or empty, and a
+    request retry may provide better input.
+
+    See :ref:`retries`.
+    """
+
+    pass
