@@ -7,10 +7,11 @@ import warnings
 from collections import deque
 from dataclasses import dataclass, field
 from operator import attrgetter
-from typing import Any, Callable, Dict, Iterable, List, Optional, Type, TypeVar, Union
+from typing import Any, Dict, Iterable, List, Optional, Type, TypeVar, Union
 
 from url_matcher import Patterns
 
+from web_poet.pages import ItemPage
 from web_poet.utils import as_list
 
 Strings = Union[str, Iterable[str]]
@@ -46,8 +47,8 @@ class OverrideRule:
     """
 
     for_patterns: Patterns
-    use: Callable
-    instead_of: Callable
+    use: Type[ItemPage]
+    instead_of: Type[ItemPage]
     meta: Dict[str, Any] = field(default_factory=dict)
 
     def __hash__(self):
@@ -69,10 +70,10 @@ class PageObjectRegistry(dict):
 
     .. code-block:: python
 
-        from web_poet import handle_urls, default_registry, ItemWebPage
+        from web_poet import handle_urls, default_registry, WebPage
 
         @handle_urls("example.com", overrides=ProductPageObject)
-        class ExampleComProductPage(ItemWebPage):
+        class ExampleComProductPage(WebPage):
             ...
 
         override_rules = default_registry.get_overrides()
@@ -96,7 +97,9 @@ class PageObjectRegistry(dict):
     """
 
     @classmethod
-    def from_override_rules(cls: Type[PageObjectRegistryTV], rules: List[OverrideRule]) -> PageObjectRegistryTV:
+    def from_override_rules(
+        cls: Type[PageObjectRegistryTV], rules: List[OverrideRule]
+    ) -> PageObjectRegistryTV:
         """An alternative constructor for creating a :class:`~.PageObjectRegistry`
         instance by accepting a list of :class:`~.OverrideRule`.
 
@@ -109,7 +112,7 @@ class PageObjectRegistry(dict):
         self,
         include: Strings,
         *,
-        overrides: Callable,
+        overrides: Type[ItemPage],
         exclude: Optional[Strings] = None,
         priority: int = 500,
         **kwargs,
@@ -229,7 +232,9 @@ def _walk_module(module: str) -> Iterable:
     mod = importlib.import_module(spec.name)
     yield mod
     if spec.submodule_search_locations:
-        for info in pkgutil.walk_packages(spec.submodule_search_locations, f"{spec.name}.", onerror):
+        for info in pkgutil.walk_packages(
+            spec.submodule_search_locations, f"{spec.name}.", onerror
+        ):
             mod = importlib.import_module(info.name)
             yield mod
 
